@@ -18,7 +18,7 @@
 
 #include <config.h>
 
-#include <gnome-db.h>
+#include <libgnomedb/gnome-db-list.h>
 #include "../gb.h"
 
 /* Include the 21x21 icon pixmap for this widget, to be used in the palette */
@@ -43,26 +43,22 @@ static GbWidget gbwidget;
  * If a dialog box is used to initialize the widget, return NULL from this
  * function, and call data->callback with your new widget when it is done.
  */
-/*
 static GtkWidget*
 gb_gnome_db_list_new (GbWidgetNewData *data)
 {
-
+	return gnome_db_list_new ();
 }
-*/
 
 
 
 /*
  * Creates the components needed to edit the extra properties of this widget.
  */
-/*
 static void
 gb_gnome_db_list_create_properties (GtkWidget * widget, GbWidgetCreateArgData * data)
 {
 
 }
-*/
 
 
 
@@ -70,13 +66,11 @@ gb_gnome_db_list_create_properties (GtkWidget * widget, GbWidgetCreateArgData *
  * Gets the properties of the widget. This is used for both displaying the
  * properties in the property editor, and also for saving the properties.
  */
-/*
 static void
 gb_gnome_db_list_get_properties (GtkWidget *widget, GbWidgetGetArgData * data)
 {
 
 }
-*/
 
 
 
@@ -84,13 +78,11 @@ gb_gnome_db_list_get_properties (GtkWidget *widget, GbWidgetGetArgData * data)
  * Sets the properties of the widget. This is used for both applying the
  * properties changed in the property editor, and also for loading.
  */
-/*
 static void
 gb_gnome_db_list_set_properties (GtkWidget * widget, GbWidgetSetArgData * data)
 {
 
 }
-*/
 
 
 
@@ -99,13 +91,11 @@ gb_gnome_db_list_set_properties (GtkWidget * widget, GbWidgetSetArgData * data)
  * Add commands to aid in editing a GnomeDbList, with signals pointing to
  * other functions in this file.
  */
-/*
 static void
 gb_gnome_db_list_create_popup_menu (GtkWidget * widget, GbWidgetCreateMenuData * data)
 {
 
 }
-*/
 
 
 
@@ -119,7 +109,7 @@ gb_gnome_db_list_write_source (GtkWidget * widget, GbWidgetWriteSourceData * dat
 {
   if (data->create_widget)
     {
-      source_add (data, "  %s = gnome_db_list_new (NULL, 0);\n", data->wname);
+      source_add (data, "  %s = gnome_db_list_new ();\n", data->wname);
     }
   gb_widget_write_standard_source (widget, data);
 }
@@ -135,7 +125,8 @@ GbWidget*
 gb_gnome_db_list_init ()
 {
   /* Initialise the GTK type */
-  gnome_db_list_get_type();
+  volatile GtkType type;
+  type = gnome_db_list_get_type();
 
   /* Initialize the GbWidget structure */
   gb_widget_init_struct(&gbwidget);
@@ -146,13 +137,11 @@ gb_gnome_db_list_init ()
 
   /* Fill in any functions that this GbWidget has */
   gbwidget.gb_widget_write_source	= gb_gnome_db_list_write_source;
-/*
   gbwidget.gb_widget_new		= gb_gnome_db_list_new;
   gbwidget.gb_widget_create_properties	= gb_gnome_db_list_create_properties;
   gbwidget.gb_widget_get_properties	= gb_gnome_db_list_get_properties;
   gbwidget.gb_widget_set_properties	= gb_gnome_db_list_set_properties;
   gbwidget.gb_widget_create_popup_menu	= gb_gnome_db_list_create_popup_menu;
-*/
 
   return &gbwidget;
 }
